@@ -5,19 +5,28 @@ from types import SimpleNamespace
 Routes = SimpleNamespace(
     healthcheck="healthcheck",
     login="login",
+    api_key_login="login/api_key",
     get_token="get-token",
     current_user="current_user",
     projects="projects",
+    project="projects/{project_id}",
     all_projects="projects/all",
     templates="projects/{project_id}/templates",
     template="projects/{project_id}/templates/{template_id}",
     versions="projects/{project_id}/templates/{template_id}/versions",
     version="projects/{project_id}/templates/{template_id}/versions/{version}",
-    dataset="projects/{project_id}/upload_prompt_dataset",
-    cost="projects/{project_id}/prompts/cost",
+    version_from_name="projects/{project_id}/templates/versions",
+    dataset="projects/{project_id}/prompt_datasets",
     runs="projects/{project_id}/runs",
     rows="projects/{project_id}/runs/{run_id}/prompts/rows",
+    export_rows="projects/{project_id}/runs/{run_id}/prompts/export_prompt_dataset",
     jobs="jobs",
+    prompt_run="projects/{project_id}/prompts/runs/{run_id}",
+    run_jobs="projects/{project_id}/runs/{run_id}/jobs",
     metrics="projects/{project_id}/runs/{run_id}/metrics",
+    user_submitted_metrics=("projects/{project_id}/runs/{run_id}/prompts/scorers/user_submitted"),
     integrations="integrations/{integration_name}",
+    registered_scorers="registered-scorers",
+    registered_scorer="registered-scorers/{registered_scorer_id}",
+    chain_rows="projects/{project_id}/runs/{run_id}/chains/ingest",
 )
